@@ -2,19 +2,19 @@
 
 from __future__ import annotations
 
+from functools import cached_property
 from os import PathLike, environ, fspath, path
+from re import compile as regex
 from secrets import token_urlsafe
 from shlex import shlex
-from re import compile as regex
 from shutil import move
 from tempfile import mkstemp
-from typing import overload, Dict, Iterator, List, Optional, Tuple, Union
+from typing import Dict, Iterator, List, Optional, Tuple, Union
 
 from . import db, email, utils
 
-
-class EnvError(Exception):
-    """Exception class representing a dotenv error."""
+EnvError = type('EnvError', (Exception,), {})
+EnvError.__doc__ = 'Exception class representing a dotenv error.'
 
 
 class EnvVar:
@@ -33,7 +33,7 @@ class EnvVar:
     key: str
     value: str
 
-    def __new__(cls, line: str) -> Optional[EnvVar]:  # type: ignore[misc]
+    def __new__(cls, line: str) -> Optional[EnvVar]:  # type: ignore
         """
         Parse a line and return a new instance or ``None``.
 
@@ -209,7 +209,7 @@ class Env(PathLike):
         EnvError
             If the environment variable is missing.
         """
-        value = self.ENV.get(key, self.vars.get(key))
+        value = self.vars.get(key)
         if value is None:
             raise EnvError(f"Missing environment variable: '{key}'")
         return value
@@ -322,15 +322,15 @@ class Env(PathLike):
         """
         return f"Env('{self.envfile}')"
 
-    @utils.cached_property  # type: ignore[misc]
+    @cached_property
     def vars(self) -> Dict[str, str]:
         """`Dict[str, str]` : Get the environment variables as a ``dict``."""
-        def _sub_callback(match):  # type: ignore[no-untyped-def]
+        def _sub_callback(match):  # type: ignore
             return {**self.ENV, **result}.get(match.group(1), '')
 
         with open(self.envfile, 'r') as f:
             envvars = list(filter(None.__ne__, map(EnvVar, f.readlines())))
-            result = dict(envvars)  # type: ignore[arg-type]
+            result = dict(envvars)  # type: ignore
 
         # substitute variables that can be interpolated
         posix = regex(r'\$\{([^}].*)?\}')
@@ -343,12 +343,6 @@ class Env(PathLike):
         """Add the variables defined in the dotenv file to :os:`environ`."""
         self.ENV.update(self.vars)
 
-    @overload
-    def get(self, key: str, default: str) -> str: ...
-
-    @overload
-    def get(self, key: str, default: None = None) -> Optional[str]: ...
-
     def get(self, key: str, default: Optional[str] = None) -> Optional[str]:
         """
         Return an environment variable or a default value.
@@ -372,12 +366,6 @@ class Env(PathLike):
         """
         return self.ENV.get(key, self.vars.get(key) or default)
 
-    @overload
-    def bool(self, key: str, default: bool) -> bool: ...
-
-    @overload
-    def bool(self, key: str, default: None = None) -> Optional[bool]: ...
-
     def bool(self, key: str, default: Optional[bool] = None) -> Optional[bool]:
         """
         Return an environment variable as a ``bool``, or a default value.
@@ -413,12 +401,6 @@ class Env(PathLike):
             return False
         raise EnvError(f"Invalid boolean value: '{value}'")
 
-    @overload
-    def int(self, key: str, default: int) -> int: ...
-
-    @overload
-    def int(self, key: str, default: None = None) -> Optional[int]: ...
-
     def int(self, key: str, default: Optional[int] = None) -> Optional[int]:
         """
         Return an environment variable as an ``int``, or a default value.
@@ -453,12 +435,6 @@ class Env(PathLike):
         except ValueError:
             raise EnvError(f"Invalid integer value: '{value}'")
 
-    @overload
-    def float(self, key: str, default: float) -> float: ...
-
-    @overload
-    def float(self, key: str, default: None = None) -> Optional[float]: ...
-
     def float(self, key: str, default:
               Optional[float] = None) -> Optional[float]:
         """
@@ -494,13 +470,6 @@ class Env(PathLike):
         except ValueError:
             raise EnvError(f"Invalid numerical value: '{value}'")
 
-    @overload
-    def list(self, key: str, default: List, separator: str = ...) -> List: ...
-
-    @overload
-    def list(self, key: str, default: None = None,
-              separator: str = ...) -> Optional[List]: ...
-
     def list(self, key: str, default: Optional[List] = None,
              separator: str = ',') -> Optional[List]:
         """
@@ -530,12 +499,6 @@ class Env(PathLike):
             return default
         return value.split(separator)
 
-    @overload
-    def db(self, key: str, default: str) -> db.DBConfig: ...
-
-    @overload
-    def db(self, key: str, default: None = None) -> Optional[db.DBConfig]: ...
-
     def db(self, key: str, default:
            Optional[str] = None) -> Optional[db.DBConfig]:
         """
@@ -570,13 +533,6 @@ class Env(PathLike):
         except Exception as e:
             raise EnvError(f"Invalid database URL: '{value}'") from e
 
-    @overload
-    def email(self, key: str, default: str) -> email.EmailConfig: ...
-
-    @overload
-    def email(self, key: str, default: None = None
-              ) -> Optional[email.EmailConfig]: ...
-
     def email(self, key: str, default:
               Optional[str] = None) -> Optional[email.EmailConfig]:
         """
